export(
# widget functions
# rp,
# rp.assign,  
  rp.block, 
  rp.button,
  rp.checkbox,
# rp.checkbox.change,
  rp.clearlines,
  rp.combo,
  rp.contingency,
  rp.control,
  rp.control.dispose,
  rp.deleteline,
  rp.do, 
  rp.doublebutton,
# rp.env,
  rp.grid,
  rp.image,
  rp.line,
  rp.listbox,
  rp.menu,
  rp.messagebox,
  rp.notebook,
  rp.notebook.raise,
  rp.pos,
  rp.radiogroup,
  rp.screenresolution,
# rp.settings,
# rp.setup,
  rp.slider,
  rp.slider.change,
  rp.text,
  rp.text.change,
  rp.textentry, 
  rp.timer,
  rp.tkrplot,
  rp.tkrreplot,
  rp.widget.dispose,
  rp.var.get,
  rp.var.put,
# rp.control.get,
  rp.control.put,
  rp.panel, # hangover from old version, just a wrapper for rp.control.get

# cartoon functions
  rp.ancova,
  rp.anova,
  rp.bubbleplot,
  rp.cartoons,
  rp.ci, 
  rp.coefficients,
  rp.colour.key,
  rp.colours,
  rp.colors,
  rp.contingency,
  rp.datalink,
  rp.drop1,
  rp.firth,
  rp.geosim, 
  rp.gulls, 
  rp.likelihood,
  rp.lm,
  rp.logistic,
# rp.multilevel,
  rp.mururoa, 
  rp.normal, 
  rp.plot3d,
  rp.plot4d,
  rp.power,
  rp.sample,
  rp.spacetime,
  rp.surface,
  rp.regression, 
  rp.regression2,
  rp.rmplot, 
  rp.tables,
  rp.t_test,
  rp.wrangle
)

import(tcltk)
importFrom("grDevices", "col2rgb", "grey", "heat.colors", "rgb2hsv",
           "terrain.colors", "topo.colors", "dev.off", "png")
importFrom("graphics", "abline", "axTicks", "axis", "box", "hist",
           "image", "layout", "lines", "mtext", "par", "persp", "plot",
           "points", "polygon", "rect", "segments", "strheight",
           "text", "title")
importFrom("stats", "contrasts", "formula", "as.formula", "qnorm", "terms",
           "binomial", "coef", "dnorm",
           "fitted", "glm", "lm", "na.exclude", "optim", "pnorm",
           "qqnorm", "qt", "rnorm", "runif", "sd", "pf", "approx",
           "coefficients", "density", "df", "drop1",
           "dt", "model.frame", "model.matrix", "qf", "rbinom",
           "t.test", "update")
importFrom("utils", "demo", "menu")
